#
# Copyright (c) 2008-2016 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.schema.fieldproperty import FieldProperty

from pyams_skin.interfaces.extension import FACEBOOK_INFO_KEY, GOOGLE_ANALYTICS_INFO_KEY, \
    GOOGLE_TAGS_INFO_KEY, IFacebookSiteInfo, IGoogleAnalyticsInfo, \
    IGoogleTagManagerInfo, IUserReportInfo, USER_REPORT_INFO_KEY
from pyams_utils.adapter import adapter_config, get_annotation_adapter
from pyams_utils.factory import factory_config
from pyams_utils.interfaces.site import ISiteRoot


@factory_config(IGoogleTagManagerInfo)
class GoogleTagManagerInfo(Persistent):
    """Google tag manager settings class"""

    enabled = FieldProperty(IGoogleTagManagerInfo['enabled'])
    on_accepted_cookie = FieldProperty(IGoogleTagManagerInfo['on_accepted_cookie'])
    cookie_name = FieldProperty(IGoogleTagManagerInfo['cookie_name'])
    rejected_cookie_value = FieldProperty(IGoogleTagManagerInfo['rejected_cookie_value'])
    container_id = FieldProperty(IGoogleTagManagerInfo['container_id'])
    activation_mode = FieldProperty(IGoogleTagManagerInfo['activation_mode'])


@adapter_config(context=ISiteRoot, provides=IGoogleTagManagerInfo)
def google_tag_manager_info_factory(context):
    """Google Tag Manager settings factory"""
    return get_annotation_adapter(context, GOOGLE_TAGS_INFO_KEY, IGoogleTagManagerInfo,
                                  notify=False, locate=False)


@factory_config(IGoogleAnalyticsInfo)
class GoogleAnalyticsInfo(Persistent):
    """Google Analytics settings class"""

    enabled = FieldProperty(IGoogleAnalyticsInfo['enabled'])
    on_accepted_cookie = FieldProperty(IGoogleAnalyticsInfo['on_accepted_cookie'])
    cookie_name = FieldProperty(IGoogleAnalyticsInfo['cookie_name'])
    rejected_cookie_value = FieldProperty(IGoogleAnalyticsInfo['rejected_cookie_value'])
    website_id = FieldProperty(IGoogleAnalyticsInfo['website_id'])
    verification_code = FieldProperty(IGoogleAnalyticsInfo['verification_code'])
    activation_mode = FieldProperty(IGoogleAnalyticsInfo['activation_mode'])


@adapter_config(context=ISiteRoot, provides=IGoogleAnalyticsInfo)
def google_analytics_info_factory(context):
    """Google Analytics settings factory"""
    return get_annotation_adapter(context, GOOGLE_ANALYTICS_INFO_KEY, IGoogleAnalyticsInfo,
                                  notify=False, locate=False)


@factory_config(IUserReportInfo)
class UserReportInfo(Persistent):
    """User report settings class"""

    enabled = FieldProperty(IUserReportInfo['enabled'])
    on_accepted_cookie = FieldProperty(IUserReportInfo['on_accepted_cookie'])
    cookie_name = FieldProperty(IUserReportInfo['cookie_name'])
    rejected_cookie_value = FieldProperty(IUserReportInfo['rejected_cookie_value'])
    account_id = FieldProperty(IUserReportInfo['account_id'])
    activation_mode = FieldProperty(IUserReportInfo['activation_mode'])


@adapter_config(context=ISiteRoot, provides=IUserReportInfo)
def user_report_info_factory(context):
    """User report settings factory"""
    return get_annotation_adapter(context, USER_REPORT_INFO_KEY, IUserReportInfo,
                                  notify=False, locate=False)


@factory_config(IFacebookSiteInfo)
class FacebookSiteInfo(Persistent):
    """Facebook site verification"""

    enabled = FieldProperty(IFacebookSiteInfo['enabled'])
    verification_code = FieldProperty(IFacebookSiteInfo['verification_code'])


@adapter_config(context=ISiteRoot, provides=IFacebookSiteInfo)
def facebook_info_factory(context):
    """Facebook site info factory"""
    return get_annotation_adapter(context, FACEBOOK_INFO_KEY, IFacebookSiteInfo,
                                  notify=False, locate=False)
